@@ -18,9 +18,13 @@ from django.template import (Context, Node, TextNode, Template,
 from django.template.defaultfilters import escape
 from django.template.loader import get_template
 from django.utils.html import strip_tags
-from django.utils.simplejson import loads
 from django.utils.text import capfirst
 
+try:
+    from json import loads
+except ImportError:  # Python < 2.6
+    from django.utils.simplejson import loads
+
 # Try to import PIL in either of the two ways it can end up installed.
 try:
     from PIL import Image, ImageFile, ImageOps
@@ -425,7 +429,7 @@ def editable(parsed, context, token):
         obj = fields[0][0]
         if isinstance(obj, Model) and is_editable(obj, context["request"]):
             field_names = ",".join([f[1] for f in fields])
-            context["form"] = get_edit_form(obj, field_names)
+            context["editable_form"] = get_edit_form(obj, field_names)
             context["original"] = parsed
             t = get_template("includes/editable_form.html")
             return t.render(Context(context))
